/*
  Enable better non-blocking concurrent connection handling.

  NOTE: 
    These commands must be run using implicit transactions. 
    Otherwise we will get: "ALTER DATABASE statement not allowed within multi-statement transaction"-exception.
*/
DECLARE @databaseName NVARCHAR(MAX)
SELECT @databaseName = DB_NAME();
DECLARE @userAccess INT;
DECLARE @recoveryModel INT;
DECLARE @isReadCommittedSnapshotOn INT;
DECLARE @snapshotIsolationState INT;
SELECT @userAccess = user_access, @isReadCommittedSnapshotOn = is_read_committed_snapshot_on, @recoveryModel = recovery_model, @snapshotIsolationState = snapshot_isolation_state FROM sys.databases WHERE name = @databaseName;

IF ((@userAccess <> 0) OR (@recoveryModel <> 3) OR (@isReadCommittedSnapshotOn <> 1) OR (@snapshotIsolationState <> 1)) BEGIN 
  DECLARE @dynamicSql NVARCHAR(MAX);
  SET @dynamicSql = '
  ALTER DATABASE [' + @databaseName + '] SET SINGLE_USER WITH ROLLBACK IMMEDIATE;
  ALTER DATABASE [' + @databaseName + '] SET ALLOW_SNAPSHOT_ISOLATION ON;
  ALTER DATABASE [' + @databaseName + '] SET READ_COMMITTED_SNAPSHOT ON;
  ALTER DATABASE [' + @databaseName + '] SET RECOVERY SIMPLE;
  ALTER DATABASE [' + @databaseName + '] SET MULTI_USER;
  '
  EXEC (@dynamicSql) 
END;
GO

CREATE STATISTICS _dta_stat_1623676832_8_1_2 ON PA_CASE(CAS_VARIATION_ID, CAS_ID, CAS_MODEL_ID);

CREATE STATISTICS _dta_stat_1863677687_3_2 ON PA_EVENT(EVT_CASE_ID, EVT_MODEL_ID);

CREATE STATISTICS _dta_stat_1863677687_4_1 ON PA_EVENT(EVT_ACTIVITY_ID, EVT_ID);

CREATE STATISTICS _dta_stat_1863677687_3_4_2 ON PA_EVENT(EVT_CASE_ID, EVT_ACTIVITY_ID, EVT_MODEL_ID);

CREATE STATISTICS _dta_stat_1863677687_1_3 ON PA_EVENT(EVT_ID, EVT_CASE_ID);

CREATE STATISTICS _dta_stat_197731907_3_4_2_5 ON PA_EVENT(EVT_CASE_ID, EVT_ACTIVITY_ID, EVT_MODEL_ID, EVT_START_TIME);
